import React from 'react';
import ReactDOM from 'react-dom';
import { scaleSqrt, max, interpolateYlOrBr, scaleSequential } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const selectedYear = '2017';

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
	const rowByCountry = new Map();

  if (!worldAtlas || !data) {
    return <pre>Loading...</pre>;
  }

  const filteredData = data.filter((d) => d.Year === '2017');
  console.log(filteredData);

  filteredData.forEach(d => {
      rowByCountry.set(d.Entity, d);
  });
  
  const colorValue = d => d.aids;
	
  const colorScale = scaleSequential(interpolateYlOrBr)
    .domain([0, max(data, colorValue)])
  
  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByCountry={rowByCountry}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
